function [Alpha,Weak_Learners,R,Time] = EasyEnsemble_Boosting_SVMLIN(X,Y,C,T)
% Plain AdaBoost algorithm (with SVMLIN base learner)
%Input
    %(X,Y): training data
    %C: regularization parameter for SVMLIN
    %T: nr of boosting rounds 
    
%initialize
m = size(X,1);
D = ones(m,1)/m;
Alpha = zeros(1,T);
Weak_Learners = cell(1,T);
R = zeros(1,T);
Time = zeros(1,T);

%First boosting round
tic;
model = Train_WeakLearner_SVMLIN(X,Y,D,C);
h_X = Predict_WeakLearner_SVMLIN(X,model);
r = sum(D.*Y.*h_X);
if ((r > 1-1e-6 && r < 1+1e6)|| r < 0)
    %r = 1 or r < 0
    Alpha(1) = 1;
    Weak_Learners{1} = model;
    R(1) = r;
    Time(1) = toc;
    return
else
    alpha = log((1+r)/(1-r))/2;
    D = D.*exp(-alpha*Y.*h_X);
    D = D/sum(D);
    %store results 
    Alpha(1) = alpha;
    Weak_Learners{1} = model;
    R(1) = r;
    Time(1) = toc; 
end

for t = 2:T
    tic;
    %train weak leaner under the current distribution D   
    model = Train_WeakLearner_SVMLIN(X,Y,D,C);
    h_X = Predict_WeakLearner_SVMLIN(X,model);%confidence rated predictions
    r = sum(D.*Y.*h_X);
    if ((r > 1-1e-6 && r < 1+1e6) || r < 0)
        Alpha(t) = 0;
        Alpha = Alpha/sum(Alpha);
        R(t) = r;
        Time(t) = toc;
        return
    else
        %choose alpha 
        alpha = log((1+r)/(1-r))/2;
        %update
        D = D.*exp(-alpha*Y.*h_X);
        D = D/sum(D);
        %store results 
        Alpha(t) = alpha;
        Weak_Learners{t} = model;
        R(t) = r;
        Time(t) = toc; 
    end
end
%update alpha
Alpha = Alpha/sum(Alpha);
end