function [AUC,Lift] = Performances_Boosting(Y,Scores,P)

%calculates the performances of a boosting process
%(for each boosting round t = 1..T)

%Input
    %Y: true labels 
    %Scores: scores of the boosting process (rows = instances, cols = t)
    %P: vector of percentages on lift curve
%Output
    %AUC: row vector of AUC's for each boosting round t
    %Lift: Lift matrix (rows = P, cols = t)

T = size(Scores,2);
AUC = zeros(1,T);
Lift = zeros(length(P),T);

%t=1
[AUC(1),Lift(:,1)] = Performances_Basic(Y,Scores(:,1),P);

%t = 2..T
for t=2:T
    if(isempty(find(Scores(:,t)~=Scores(:,t-1), 1)))
        %the scores don't change anymore
        AUC(t:end) = AUC(t-1);
        Lift(:,t:end) = repmat(Lift(:,t-1),1,T-(t-1));
    else
        [AUC(t),Lift(:,t)] = Performances_Basic(Y,Scores(:,t),P);
    end
end

